==> de-BBBike-3.01.tgz: BBBike/BBBikeMenubar.pm <==
# -*- perl -*-

#
# $Id: BBBikeMenubar.pm,v 1.3 2000/12/17 23:45:25 eserte Exp $
# Author: Slaven Rezic
#
# Copyright (C) 2000 Slaven Rezic. All rights reserved.
# This package is free software; you can redistribute it and/or
# modify it under the same terms as Perl itself.
#
# Mail: eserte@cs.tu-berlin.de
# WWW:  http://user.cs.tu-berlin.de/~eserte/
#

package BBBike::Menubar;

=head1 NAME

BBBike::Menubar - optional conventional menubar for bbbike

=cut

# keine echte OO_Klasse!

use vars qw($file_menu);

sub new {
    my($class, $context) = @_;
    my $self = {};
    while(my($k,$v) = each %$context) {
	$self->{$k} = $v;
    }
    bless $self, $class;
}

sub bbbike_context {
    +{Top        => $main::top,
      MiscFrame  => $main::misc_frame,
      MiscFrame2 => $main::misc_frame2,

      OpenCommand  => sub { main::load_save_route(0) },
      SaveCommand  => sub { main::load_save_route(1) },
      PrintCommand => \&main::print_function,
      ExitCommand  => \&main::exit_app,
     };
}

sub menubar {
    my $self = shift;
    my $top = $self->{Top} || die "Top missing in context";
    my $mb = $top->cget(-menu);
    # existiert bereits:    my $file_menu = $mb->cascade(-label => 'Datei');
    $file_menu->command(-label => "ffnen ...",
			-command => $self->{OpenCommand});
    my $open_menu = $file_menu->cascade(-label => "zuletzt geffnete Dateien");
    $file_menu->command(-label => "Speichern ...",
			-command => $self->{SaveCommand});
    my $save_menu = $file_menu->cascade(-label => "Exportieren");
    $file_menu->command(-label => "Drucken ...",
			-command => $self->{PrintCommand});
    my $print_menu = $file_menu->cascade(-label => "Druckeinstellungen");
    $file_menu->command(-label => "Beenden",
			-command => $self->{ExitCommand});

    my $layer_menu = $mb->cascade(-label => 'Kartenebenen');

    foreach my $c ($self->{MiscFrame}->children,
		   $self->{MiscFrame2}->children
		  ) {
	if ($c->isa('Tk::Menubutton')) {
	    my $menu = $c->cget(-menu);
	    my $menulabel =
		$menu->{BBBike_Menulabel} ||
		eval q{$menu->entrycget(1, -label)};
	    my $special = $menu->{BBBike_Special};
	    if (defined $special) {
		if ($special eq 'ffnen') {
		    $open_menu->configure(-menu => $menu);
		} elsif ($special eq 'Speichern') {
		    $save_menu->configure(-menu => $menu);
		} elsif ($special eq 'Drucken') {
		    $print_menu->configure(-menu => $menu);
		} elsif ($special eq 'Layer') {
		    $layer_menu->cascade(-menu => $menu,
					 -label => $menulabel);
		} else {
		    die "Unknown -special: $special";
		}
	    } elsif (defined $menulabel) {
		$mb->cascade(-menu => $menu,
			     -label => $menulabel);
	    } else {
		warn "no menulabel defined for $c";
	    }
	}
    }
#XXX nicht ntig??? DEL:    $top->configure(-menu => $mb);
}

sub Set {
    my $bmb = new BBBike::Menubar bbbike_context();
    $bmb->menubar;
}

# erstellt Menubar und reserviert Platz...
sub EmptyMenubar {
    my $top = bbbike_context()->{Top};
    my $menu = $top->Menu;
    $file_menu = $menu->cascade(-label => "Datei");
    $top->configure(-menu => $menu);
}

1;

__END__

==> de-BBBike-3.03.tgz: BBBike/BBBikeMenubar.pm <==
# -*- perl -*-

#
# $Id: BBBikeMenubar.pm,v 1.5 2001/03/25 17:11:09 eserte Exp $
# Author: Slaven Rezic
#
# Copyright (C) 2000 Slaven Rezic. All rights reserved.
# This package is free software; you can redistribute it and/or
# modify it under the same terms as Perl itself.
#
# Mail: eserte@cs.tu-berlin.de
# WWW:  http://user.cs.tu-berlin.de/~eserte/
#

package BBBike::Menubar;

=head1 NAME

BBBike::Menubar - optional conventional menubar for bbbike

=cut

# keine echte OO_Klasse!

BEGIN {
    if (!eval '
use blib "/home/e/eserte/src/perl/Msg";
use Msg qw(frommain);
1;
') {
	warn $@ if $@;
	eval 'sub M ($) { $_[0] }';
	eval 'sub Mfmt { sprintf(shift, @_) }';
    }
}

use vars qw($file_menu);

sub new {
    my($class, $context) = @_;
    my $self = {};
    while(my($k,$v) = each %$context) {
	$self->{$k} = $v;
    }
    bless $self, $class;
}

sub bbbike_context {
    +{Top        => $main::top,
      MiscFrame  => $main::misc_frame,
      MiscFrame2 => $main::misc_frame2,

      OpenCommand  => sub { main::load_save_route(0) },
      SaveCommand  => sub { main::load_save_route(1) },
      PrintCommand => \&main::print_function,
      ExitCommand  => \&main::exit_app,
     };
}

sub menubar {
    my $self = shift;
    my $top = $self->{Top} || die "Top missing in context";
    my $mb = $top->cget(-menu);
    # existiert bereits:    my $file_menu = $mb->cascade(-label => 'Datei');
    $file_menu->command(-label => M("ffnen")." ...",
			-command => $self->{OpenCommand});
    my $open_menu = $file_menu->cascade(-label => M"zuletzt geffnete Dateien");
    $file_menu->command(-label => M("Speichern")." ...",
			-command => $self->{SaveCommand});
    my $save_menu = $file_menu->cascade(-label => M"Exportieren");
    $file_menu->command(-label => M("Drucken")." ...",
			-command => $self->{PrintCommand});
    my $print_menu = $file_menu->cascade(-label => M"Druckeinstellungen");
    $file_menu->command(-label => M"Beenden",
			-command => $self->{ExitCommand});

    my $layer_menu = $mb->cascade(-label => M"Kartenebenen");

    foreach my $c ($self->{MiscFrame}->children,
		   $self->{MiscFrame2}->children
		  ) {
	if ($c->isa('Tk::Menubutton')) {
	    my $menu = $c->cget(-menu);
	    my $menulabel =
		$menu->{BBBike_Menulabel} ||
		eval q{$menu->entrycget(1, -label)};
	    my $special = $menu->{BBBike_Special};
	    if (defined $special) {
		if ($special eq 'OPEN') {
		    $open_menu->configure(-menu => $menu);
		} elsif ($special eq 'SAVE') {
		    $save_menu->configure(-menu => $menu);
		} elsif ($special eq 'PRINT') {
		    $print_menu->configure(-menu => $menu);
		} elsif ($special eq 'LAYER') {
		    $layer_menu->cascade(-menu => $menu,
					 -label => $menulabel);
		} else {
		    die "Unknown -special: $special";
		}
	    } elsif (defined $menulabel) {
		$mb->cascade(-menu => $menu,
			     -label => $menulabel);
	    } else {
		warn "no menulabel defined for $c";
	    }
	}
    }
#XXX nicht ntig??? DEL:    $top->configure(-menu => $mb);
}

sub Set {
    my $bmb = new BBBike::Menubar bbbike_context();
    $bmb->menubar;
}

# erstellt Menubar und reserviert Platz...
# XXX evtl. set_temporary_state aus dem repository verwenden
sub EmptyMenubar {
    my $top = bbbike_context()->{Top};
    my $menu = $top->Menu;
    $file_menu = $menu->cascade(-label => M"Datei");
    $top->configure(-menu => $menu);
}

1;

__END__
